//
// Copyright (C) 1999-2006 WideStudio/MWT Project Team
//
// Permission is hereby granted, free of charge, to any person obtaining a copy
// of this software and associated documentation files (the "Software"), to
// deal in the Software without restriction, including without limitation the
// rights to use, copy, modify, merge, publish, distribute, sublicense, and/or
// sell copies of the Software, and to permit persons to whom the Software is
// furnished to do so, subject to the following conditions:
//
// The above copyright notice and this permission notice shall be included in
// all copies or substantial portions of the Software.
//
// THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
// IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
// FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
// THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
// LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
// OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
// SOFTWARE.
//

#include <nx/WSDnxNwDev.h>
#include <nx/WSDnxAppDev.h>
#include <nx/WSDnxDraw.h>
#include <WSCdevice.h>
#include <WSCbase.h>

WSMFclassInit(WSDnxNwDev,WSDnwDev);

WSDdev* _wsdnxNwdev_init_(){
  return new WSDnxNwDev();
}

#ifndef NO_GLOBAL_CONSTRUCTORS
class _WSDnxNwDev_init_ {
  public:_WSDnxNwDev_init_(){
     WSGIappDevice()->setCreateHandler("nwDev",_wsdnxNwdev_init_);
  };
};
static _WSDnxNwDev_init_ _init_to_run_WSDnxNwDev_;
#endif

static WSDnxDraw* draw_of_nxNw = NULL;

WSDnxNwDev::WSDnxNwDev(){
WSMFtrace("WSDnxNwDev::WSDnxNwDev 0x%x 0x%x\n",this,*(long*)this);
  if (draw_of_nxNw == NULL){
    draw_of_nxNw = new WSDnxDraw();
  }
  setDraw(draw_of_nxNw);
}

WSDnxNwDev::~WSDnxNwDev(){
}

long WSDnxNwDev::_copy_pixmap_to_window(){
  return WS_NO_ERR;
}
long WSDnxNwDev::getContextResource(){
  WSDdev* parent = getParentDev();
  if (parent == NULL){
    return -1;
  }
  return parent->getContextResource(); 
}
long WSDnxNwDev::setValue(long kind,void* data){
  if (kind == WSDEV_USE_PIXMAP){
    return WS_NO_ERR;
  }
  return WSDnwDev::setValue(kind,data);
}
